from flask import Blueprint, request, jsonify
from .optimizer import optimize_routes
from .data_fetcher import fetch_data

api = Blueprint('api', __name__)

@api.route('/optimize', methods=['POST'])
def optimize():
    data = request.json
    lat_longs = data.get('lat_longs')
    num_drivers = data.get('num_drivers')

    if not lat_longs or not num_drivers:
        return jsonify({"error": "Invalid input"}), 400

    try:
        routes = optimize_routes(lat_longs, num_drivers)
        return jsonify(routes), 200
    except Exception as e:
        return jsonify({"error": str(e)}), 500

@api.route('/fetch', methods=['GET'])
def fetch():
    try:
        lat_longs = fetch_data()
        return jsonify(lat_longs), 200
    except Exception as e:
        return jsonify({"error": str(e)}), 500
