import requests
import pandas as pd
import numpy as np
from config import USE_EXTERNAL_API, EXTERNAL_ROUTES_API_URL, LOCAL_CSV_PATH

def fetch_data():
    """
    Fetches data either from an external API or from a local CSV file.

    Returns:
        dict or pandas.DataFrame: The fetched data.

    Raises:
        Exception: If the data fetching fails from the external API.
    """
    if USE_EXTERNAL_API:
        response = requests.get(EXTERNAL_ROUTES_API_URL)
        # on success, return the JSON response
        if response.status_code == 200:
            return response.json()
        else:
            raise Exception("Failed to fetch data from the external API.")
    else:
        return read_csv(LOCAL_CSV_PATH)

def read_csv(file_path):
    """
    Reads a file and returns a pandas DataFrame.
    Parameters:
        file_path (str): The path to the data file.
    Returns:
        pandas.DataFrame: The DataFrame containing the data from the CSV file.
    """
    
    df = pd.read_excel(file_path)  # Default

    # Split 'Coordinates' into 'latitude' and 'longitude'
    df[['latitude', 'longitude']] = df['Coordinates'].str.split(',', expand=True)
    # Drop original 'Coordinates' column
    df.drop(columns=['Coordinates'], axis=0, inplace=True)
    # Simulate a day of data so take a random number of boxes
    # up to max boxes (unlikely though)
    
    # Randomly select number of boxes
    num_boxes = np.random.randint(1, len(df))
    df = df.sample(n=num_boxes)
        
    return df
