from flask import Flask, jsonify
from data_fetcher import fetch_data
from optimizer import ORTSolver
from config import START_NODE, END_NODE, MAX_DRIVERS, POST_EXTERNAL_API, POST_EXTERNAL_API_URL
import requests
import logging

# Create a Flask instance
app = Flask(__name__)

def post_routes_if_needed(routes_dict):
    if POST_EXTERNAL_API:
        if POST_EXTERNAL_API_URL:
            try:
                response = requests.post(POST_EXTERNAL_API_URL, json=routes_dict)
                logging.debug(f"POST Response: {response.json()}")
            except requests.exceptions.RequestException as e:
                logging.error(f"Failed to post data: {e}")
        else:
            logging.error("POST_EXTERNAL_API_URL is not set.")
    else:
        logging.debug("POST_EXTERNAL_API is set to False. No action taken.")


def calculate_routes():
    logging.debug("Starting to fetch data")
    # Fetch active boxes data
    fetched_coordinates = fetch_data()
    logging.debug(f"Data fetched: {fetched_coordinates}")
    
    logging.debug("Starting optimization")
    # Create a solver instance and run the optimization algorithm
    solver = ORTSolver(fetched_coordinates, START_NODE, END_NODE, vehicles=MAX_DRIVERS)
    routes = solver.solve()
    logging.debug(f"Calculated Routes: {routes}")
    
    # Convert the solution to a dictionary
    routes_dict = {
        'routes': routes['routes'],
        'costs': routes['costs']
    }
    
    # Post the routes if needed
    post_routes_if_needed(routes_dict)
    
    return routes_dict

@app.route('/optimize', methods=['GET'])
def optimize():
    routes_json = calculate_routes()
    return routes_json

if __name__ == "__main__":
    app.run(debug=True, host="0.0.0.0")